@@ -289,6 +289,8 @@ on_pref_btn_clicked                    (GtkButton       *button,
   ttl = g_strdup_printf("%s %s v%s", _("Preferences"), prog_name,
         prog_version);
   gtk_window_set_title(GTK_WINDOW(w), ttl);
+  gtk_window_set_modal(GTK_WINDOW(w), TRUE); 
+  gtk_window_set_transient_for (GTK_WINDOW (w), nav_window);
   gtk_widget_show(w);
 }
 
