@@ -134,7 +134,8 @@ get_file_list(GArchiveReader* reader_iface,
 	    return;
 	}
 	close(pfd[1]);
-	execvp(reader->list_command[0], reader->list_command);
+	if(execvp(reader->list_command[0], reader->list_command) < 0)
+	  fprintf(stderr, "Archive list command failed (is it installed?)\n");
 	/* never reached */
 	return;
     }
@@ -165,7 +166,8 @@ get_file_list(GArchiveReader* reader_iface,
 		return;
 	    }
 	    close(pfd2[1]);
-	    execlp("grep", "grep", all_extensions, NULL);
+	    if(execlp("grep", "grep", all_extensions, NULL) < 0)
+	      fprintf(stderr, "Grep command failed (is grep in your PATH?)\n");
 	    /* never reached */
 	    return;
 	}
@@ -282,8 +284,9 @@ get_page(GArchiveReader* reader_iface,
 	    return NULL;
 	}
 	close(pfd[1]);
-	execvp(reader->decompress_command[0],
-	       reader->decompress_command);
+	if(execvp(reader->decompress_command[0],
+		  reader->decompress_command) < 0)
+	  fprintf(stderr, "Archive decompression command failed (is it installed?)\n");
 	/* never reached */
 	return NULL;
     default:
