@@ -395,20 +395,6 @@ create_toolbar(GtkWidget* connect_parent)
   gtk_widget_show(image19);
   gtk_container_add(GTK_CONTAINER(fullscreen_tbtn), image19);
 
-  toolitem17 = (GtkWidget*) gtk_tool_item_new();
-  gtk_widget_hide(toolitem17);
-  gtk_container_add(GTK_CONTAINER(nav_toolbar), toolitem17);
-
-  toggle_btn = gtk_button_new();
-  gtk_container_add(GTK_CONTAINER(toolitem17), toggle_btn);
-  gtk_button_set_relief(GTK_BUTTON(toggle_btn), GTK_RELIEF_NONE);
-  GTK_WIDGET_UNSET_FLAGS(toggle_btn, GTK_CAN_FOCUS);
-
-  image20 = gtk_image_new_from_stock("gtk-execute", GTK_ICON_SIZE_SMALL_TOOLBAR);
-  gtk_widget_show(image20);
-  gtk_container_add(GTK_CONTAINER(toggle_btn), image20);
-
-
   g_signal_connect ((gpointer) begin_btn, "clicked",
                     G_CALLBACK (on_begin_btn_clicked),
                     NULL);
@@ -456,9 +442,6 @@ create_toolbar(GtkWidget* connect_parent)
   g_signal_connect ((gpointer) fullscreen_tbtn, "clicked",
 		    G_CALLBACK(on_fullscreen_btn_clicked),
 		    NULL);
-  g_signal_connect ((gpointer) toggle_btn, "clicked",
-		    G_CALLBACK(on_toggle_btn_clicked),
-		    NULL);
 
   /* Store pointers to all widgets, for use by lookup_widget(). */
   GLADE_HOOKUP_OBJECT (connect_parent, nav_toolbar, "nav_toolbar");
@@ -500,7 +483,6 @@ create_toolbar(GtkWidget* connect_parent)
   GLADE_HOOKUP_OBJECT (connect_parent, image9, "image9");
   GLADE_HOOKUP_OBJECT (connect_parent, rotate_tbtn, "rotate_btn");
   GLADE_HOOKUP_OBJECT (connect_parent, fullscreen_tbtn, "fullscreen_btn");
-  GLADE_HOOKUP_OBJECT (connect_parent, toggle_btn, "toggle_btn");
 #if !USE_HILDON
   GLADE_HOOKUP_OBJECT (connect_parent, toolitem14, "toolitem14");
   GLADE_HOOKUP_OBJECT (connect_parent, file_list_tbtn, "file_list_tbtn");
