@@ -23,3 +23,5 @@
 
 extern GtkWidget *MainWindow;
 extern GtkWidget *nav_window;
+extern GtkWidget *nav_toolbar;
+extern GtkWidget *fullscreen_item;
